@@ -39,12 +39,14 @@ impl Rejection {
     pub fn into_response(self) -> Result<Response, Rejection> {
         match self.cause {
             Cause::Err(err) => {
-                tracing::error!(%err, "rejected");
+                let mut sources = Vec::new();
                 let mut source = err.source();
                 while let Some(err) = source {
-                    tracing::error!(%err, "-> source");
+                    sources.push(err.to_string());
                     source = err.source();
                 }
+                let sources = sources.into_iter().collect::<String>();
+                tracing::error!(%err, %sources, "rejected: {}", err);
                 err.into_response_error()
             }
             Cause::Status(status) => status.into_response(),
